Predicate-based selection utilities.
These functions are useful in areas such as reporting or constrained filtering.
Functions
- failing_
elements - Gets all elements that fail the predicate.
- pairwise
- Checks whether a binary predicate holds for all adjacent pairs.